/*!
  * iarco-ui v1.0.0
  * (c) 2022 kkb
  * @license MIT
  */
import { openBlock, createElementBlock, toRefs, inject, computed, unref, getCurrentInstance, normalizeClass, createCommentVNode, renderSlot } from 'vue';

var script$1 = {
  name: 'Alert',
};

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div"))
}

script$1.render = render$1;
script$1.__file = "packages/Alert/Alert.vue";

script$1.install = function (Vue) {
  Vue.component(script$1.name, script$1);
};

var script = {
  name: "AButton",

  props: {
    type: {
      type: String,
      default: "default",
    },
    size: {
      type: String,
      default: "",
    },
    icon: {
      type: String,
      default: "",
    },
    nativeType: {
      type: String,
      default: "button",
    },
    loading: Boolean,
    disabled: Boolean,
    plain: Boolean,
    autofocus: Boolean,
    round: Boolean,
    circle: Boolean,
  },
  emits: ["click"],
  setup(props, ctx) {
    const { size, disabled } = toRefs(props);

    const buttonSize = useButtonSize(size);
    const buttonDisabled = useButtonDisabled(disabled);

    const handleClick = (evt) => {
      ctx.emit("click", evt);
    };

    return {
      handleClick,
      buttonSize,
      buttonDisabled,
    };
  },
};

const useButtonSize = (size) => {
  const elFormItem = inject("elFormItem", {});

  const _elFormItemSize = computed(() => {
    return unref(elFormItem.elFormItemSize);
  });

  const buttonSize = computed(() => {
    return (
      size.value ||
      _elFormItemSize.value ||
      (getCurrentInstance().proxy.$ELEMENT || {}).size
    );
  });

  return buttonSize;
};

const useButtonDisabled = (disabled) => {
  const elForm = inject("elForm", {});

  const buttonDisabled = computed(() => {
    return disabled.value || unref(elForm.disabled);
  });

  return buttonDisabled;
};

const _hoisted_1 = ["disabled", "autofocus", "type"];
const _hoisted_2 = {
  key: 0,
  class: "el-icon-loading"
};
const _hoisted_3 = { key: 2 };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("button", {
    class: normalizeClass(["el-button", [
      $props.type ? 'el-button--' + $props.type : '',
      $setup.buttonSize ? 'el-button--' + $setup.buttonSize : '',
      {
        'is-disabled': $setup.buttonDisabled,
        'is-loading': $props.loading,
        'is-plain': $props.plain,
        'is-round': $props.round,
        'is-circle': $props.circle,
      },
    ]]),
    onClick: _cache[0] || (_cache[0] = (...args) => ($setup.handleClick && $setup.handleClick(...args))),
    disabled: $setup.buttonDisabled || $props.loading,
    autofocus: $props.autofocus,
    type: $props.nativeType
  }, [
    ($props.loading)
      ? (openBlock(), createElementBlock("i", _hoisted_2))
      : createCommentVNode("v-if", true),
    ($props.icon && !$props.loading)
      ? (openBlock(), createElementBlock("i", {
          key: 1,
          class: normalizeClass($props.icon)
        }, null, 2 /* CLASS */))
      : createCommentVNode("v-if", true),
    (_ctx.$slots.default)
      ? (openBlock(), createElementBlock("span", _hoisted_3, [
          renderSlot(_ctx.$slots, "default")
        ]))
      : createCommentVNode("v-if", true)
  ], 10 /* CLASS, PROPS */, _hoisted_1))
}

script.render = render;
script.__file = "packages/Button/Button.vue";

script.install = function (Vue) {
  Vue.component(script.name, script);
};

let components = [script$1, script]; // 1.支持全局注册

var index = {
  install(Vue) {
    components.forEach(() => {
      Vue.component(item.name, item);
    });
  }

}; // 2.支持按需导入
n;

export { script$1 as Alert, script as Button, index as default };
